@@ -400,7 +400,7 @@ class TimerMMAcquisition(MMAcquisition):
         )
         num_frames = self.num_channels + self.slices
 
-        step = initial_wait_time / num_frames / 2
+        step = initial_wait_time / num_frames / 4
         calibrated_time = self._ramp_calibration(initial_wait_time, step, old_settings)
 
         self.calibrated_wait_time = calibrated_time
@@ -450,7 +450,7 @@ class TimerMMAcquisition(MMAcquisition):
             self.acquisitions.set_pause(False)
             time.sleep((wait_time + step_now) / 1000)
             self.acquisitions.set_pause(True)
-            time.sleep(0.7)
+            time.sleep(1)
             missing_images = num_frames - datastore.get_num_images()
             if missing_images == 0 and first_hit is None:
                 first_hit = wait_time + step_now
@@ -462,9 +462,9 @@ class TimerMMAcquisition(MMAcquisition):
                 f"acq_time: {int(wait_time + step_now)} image_offset: {missing_images}"
             )
 
-        mean = (first_hit + wait_time + step_now) / 2
+        # mean = (first_hit + wait_time + step_now) / 2
         diff = wait_time + step_now - first_hit
-        return mean - diff * 0.33
+        return first_hit + diff * 0.75
 
     def _initial_calibration(self, old_settings):
         num_timepoints = 5
